# jQuery UI Accordion Test Suite

##

##

There is one obvious advantage:

You've seen it coming!
Buy now and get nothing for free!
Well, at least no free beer. Perhaps a bear, if you can afford it.

Now that you've got...

your bear, you have to admit it!
No, we aren't selling bears.

We could talk about renting one.

Rent one bear, ...

get two for three beer.

And now, for something completely different.